@@ -12,7 +12,6 @@ fi
 debugging.setup
 dump_state.setup
 
-scale_up_workers
 create_namespaces
 create_htpasswd_users
 add_roles
@@ -26,7 +25,19 @@ if [[ $TEST_KNATIVE_KAFKA == true ]]; then
   install_strimzi
   serverless_operator_kafka_e2e_tests
 fi
-ensure_serverless_installed
+
+if [[ $FULL_MESH == "true" ]]; then
+  # net-istio does not use knative-serving-ingress namespace.
+  export INGRESS_NAMESPACE="knative-serving"
+  UNINSTALL_MESH="false" install_mesh
+  ensure_serverless_installed
+  enable_net_istio
+else
+  ensure_serverless_installed
+fi
+
+[ -n "$OPENSHIFT_CI" ] && setup_quick_api_deprecation_alerts
+
 # Run Knative Serving & Eventing downstream E2E tests.
 downstream_serving_e2e_tests
 downstream_eventing_e2e_tests
@@ -40,4 +51,6 @@ if [[ $TEST_KNATIVE_KAFKA == true ]]; then
   # downstream_knative_kafka_e2e_tests
 fi
 
+[ -n "$OPENSHIFT_CI" ] && check_serverless_alerts
+
 success
